# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bikebd/bike/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Bikebd\\Bike\\": "packages/bikebd/bike/src",
            "Bikebd\\Bike\\Seeders\\": "packages/bikebd/bike/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bikebd\Bike\Providers\BikeServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Bike'  => Bikebd\Bike\Facades\Bike::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bikebd\\Bike\\Seeders\\BikeTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bikebd\Bike\Providers\BikeServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bikebd\Bike\Providers\BikeServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bikebd\Bike\Providers\BikeServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/bike/{modulename}

**User**

    http://path-to-route-folder/user/bike/{modulename}

**Public**

    http://path-to-route-folder/bikes


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/bike/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/bike/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/bike/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/bike/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/bike/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/bike/{modulename}/{slug}
    METHOD: GET